<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title> curriculum vita </title>
    <link rel="stylesheet" href="style.css">
</head>
<body>
    <div class="container">

        <form action= "{% url 'index' %}" method="POST" >
        {% csrf_token %}
        <header>
            <div class="mb-3">
                    <label for="nom_prenom" class="form-label"> nom et prenoms</label>
                    <input type="text" class="form-control" name="nom_prenom" id="nom_prenom" >

                    <label for="email1" class="form-label">Email address</label>
                    <input type="email" class="form-control" name="email" id="email1" aria-describedby="emailHelp">

                                <label for="numero" class="form-label"> numero</label>
                    <input type="text" class="form-control" name="numero" id="numero" >
            </div>
        </header>
        <section class="profil">
            <h2>PROFILE</h2>
            <div class="mb-3">
                      <label for="profile" class="form-label"> le profile</label>
                      <textarea class="form-control" name="profile" id="profile" rows="5"></textarea>
            </div>
        </section>

        <section class="experiences">
            <h2>EXPERIENCES</h2>
            <div class="mb-3">
                      <label for="experience" class="form-label">experience</label>
                      <textarea class="form-control" name="experience" id="experience" rows="5"></textarea>
            </div>
        </section>

        <section class="formations">
            <h2>FORMATIONS</h2>
                  <div class="mb-3">
                          <label for="formation" class="form-label">formations</label>
                          <textarea class="form-control" name="formation" id="formation" rows="5"></textarea>
            </div>
        </section>
        <button type="submit" class="btn btn-primary">Submit</button>
    </div>
  
  
</form>

<style>
body {
    font-family: Arial, sans-serif;
    background-color: #f4f4f4;
    margin: 0;
    padding: 20px;
}

.container {
    background: white;
    border-radius: 8px;
    box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
    padding: 20px;
    max-width: 600px;
    margin: auto;
}

header, section {
    margin-bottom: 20px;
}

h2 {
    color: #333;
    margin-bottom: 10px;
    border-bottom: 2px solid #007BFF;
    padding-bottom: 5px;
}

label {
    font-weight: bold;
    display: block;
    margin-bottom: 5px;
}

.form-control {
    width: 100%;
    padding: 10px;
    border: 1px solid #ccc;
    border-radius: 4px;
    margin-bottom: 15px;
    box-sizing: border-box;
}

.form-control:focus {
    border-color: #007BFF;
    outline: none;
}

.mb-3 {
    margin-bottom: 15px;
}

button {
    background-color: #007BFF;
    color: white;
    border: none;
    padding: 10px 15px;
    border-radius: 4px;
    cursor: pointer;
}

button:hover {
    background-color: #0056b3;
}

</style>
</body>
</html>