# Generated by Django 5.2.4 on 2025-07-25 07:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_cv1', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='personne',
            name='nom_prenom',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='adresse',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='email',
            field=models.EmailField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='experience',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='formation',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='numero',
            field=models.CharField(blank=True, max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='personne',
            name='profile',
            field=models.TextField(blank=True, null=True),
        ),
    ]
